<div id="flashed-messages">
  {% with messages = get_flashed_messages() %}
    {% if messages %}
      {% for message in messages %}
        {{ message | safe}}
      {% endfor %}
    {% endif %}
  {% endwith %}
</div>
