<p class="h2">Register</p>

<div class="form-group">
    <div class="input-group mb-3">
        <div class="input-group-prepend">
            <span class="input-group-text"><i class="fa fa-id-card"></i></span>
        </div>
        {{ form.email(class_="form-control", placeholder="Email", autocomplete="off", autofocus=true) }}
    </div>
    <ul class="form-errors">
        {% for error in form.email.errors %}
            <li>{{ error }}</li>
        {% endfor %}
    </ul>
</div>
<div class="form-group">
    <div class="input-group mb-3">
        <div class="input-group-prepend">
            <span class="input-group-text"><i class="fa fa-key"></i></span>
        </div>
        {{ form.password(class_="form-control", placeholder="Password") }}
    </div>
    <ul class="form-errors">
        {% for error in form.password.errors %}
            <li>{{ error }}</li>
        {% endfor %}
    </ul>
</div>
<div class="form-group">
    <div class="input-group mb-3">
        <div class="input-group-prepend">
            <span class="input-group-text"><i class="fa fa-key"></i></span>
        </div>
        {{ form.confirm(class_="form-control", placeholder="Confirm Password") }}
    </div>
    <ul class="form-errors">
        {% for error in form.confirm.errors %}
            <li>{{ error }}</li>
        {% endfor %}
    </ul>
</div>

<input type="hidden" name="csrf_token" value="{{ csrf_token() }}"/>
<input type="submit" name="" value="register" class="btn btn-info">
