

{% from "base/blocks/macros.html" import sidebar_item with context %}

<!doctype html>
<html lang="en">
<head>

    {% include 'base/blocks/default_styles.html'%}
    {% block pagehead %}{% endblock %}


    {% include 'base/blocks/resources.html'%}
</head>
<body>
    {% include 'base/nav_base.html'%}
    {% include 'base/blocks/flashed_messages.html'%}

  <div class="d-flex bg-white " id="wrapper">

    <!-- Sidebar -->
    <div class="bg-white border-right" id="sidebar-wrapper">
      <!--TODO: module info['display string']-->
      <div class="sidebar-heading"><a href=""></a></div>
      <div class="list-group list-group-flush" >
        {% block sidebar %}{% endblock %}
      </div>
    </div>
    <!-- /#sidebar-wrapper -->

    <!-- Page Content -->
    <div id="page-content-wrapper" >

      <nav class="navbar navbar-expand-lg navbar-light bg-light border-bottom">
        <button class="btn btn-primary" id="menu-toggle">Sidebar</button>

        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
          <span class="navbar-toggler-icon"></span>
        </button>

        <div class="collapse navbar-collapse" id="navbarSupportedContent">
          <ul class="navbar-nav ml-auto mt-2 mt-lg-0">
            <!--
            <li class="nav-item">
              <a class="nav-link" href="">Logout</a>
            </li>

            <li class="nav-item dropdown">
              <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                Dropdown
              </a>
              <div class="dropdown-menu dropdown-menu-right" aria-labelledby="navbarDropdown">
                <a class="dropdown-item" href="#">Action</a>
                <a class="dropdown-item" href="#">Another action</a>
                <div class="dropdown-divider"></div>
                <a class="dropdown-item" href="#">Something else here</a>
              </div>
            </li>
          -->
          </ul>
        </div>
      </nav>
      <div class="container-fluid shopyo-module-area">

        {% block content %}{% endblock %}

      </div>
    </div>
    <!-- /#page-content-wrapper -->

  </div>
  <!-- /#wrapper -->



  <!-- Menu Toggle Script -->
  <script>
    $("#menu-toggle").click(function(e) {
      e.preventDefault();
      $("#wrapper").toggleClass("toggled");
    });
  </script>
  {% include 'base/blocks/footer.html'%}

</body>
</html>
