{%set active_page = 'shop.html'%}
{% extends "shop/base.html" %}
{% block pagehead %}

{% endblock %}
{% block content %}
<div class="shop-spacer-1">
</div>
<div class="container">
    <div class="card">
        <div class="card-body">
            <form action="{{ url_for('auth.shop_login') }}" method="post">
                 {%include 'auth/blocks/login_form.html'%}
            </form>
        </div>
    </div>

</div>
    {% endblock %}
