<footer class="pt-4 my-md-5 pt-md-5 border-top">
    <div class="container">
        <div class="row">
          <div class="col-12">

            <small class="d-block mb-3 text-muted">
            	&copy; {{APP_NAME}}. Powered by <a href="https://www.github.com/Abdur-RahmaanJ/Shopyo">Shopyo</a>.

            </small>
          </div>

        </div>
    </div>

</footer>
