<link rel="icon" href="/static/shopyo.png">
<!--<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.0/css/bootstrap.min.css">-->
<link rel="stylesheet" href="/static/bootstrap.min.css">
<!--<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">-->
<link rel="stylesheet" href="/static/fontawesome/css/all.css">
<!--<link rel="stylesheet" href="{{ url_for('static', filename = 'style.css') }}">-->



<meta name="viewport" content="width=device-width, initial-scale=1.0">

<script src="/static/jquery_3.2.1.min.js"></script>
<script src="{{ url_for('static', filename ='bootstrap.bundle.min.js') }}"></script>
<script src="{{ url_for('static', filename ='js/python.js') }}"></script>
<!--<script type="text/javascript" src="{{ url_for('static', filename = 'logic.js') }}"></script>-->

<link href="{{ url_for('static', filename ='css/simple_sidebar.css') }}" rel="stylesheet">


<link rel="stylesheet" href="{{get_active_back_theme_styles_url()}}">
