<!DOCTYPE html>
<html>
<head>
	<title></title>
</head>
<body>
	<p>Shopyo is now running! Please consult the <a href="https://shopyo.readthedocs.io/">docs</a> or join the <a href="https://discord.gg/k37Ef6w">Discord community</a>.</p>
	<p>Otherwise, go right ahead to the <a href="/dashboard">dashboard</a> to get started by logging in with email <code>admin@domain.com</code> and password <code>pass</code>.</p><br>
	<p>
		Make sure to run <pre>shopyo initialise</pre> to initialise the db if you are using the default modules!
	</p>
</body>
</html>
