# global templates variables in here
# available_everywhere = {
#
# }
# global configs in here, defined by profile
# configs = {
#     "development": {
#         "CONFIG_VAR": "DEVVALUE"
#     },
#     "production": {
#         "CONFIG_VAR": "PRODVALUE"
#     },
#     "testing": {
#         "CONFIG_VAR": "TESTVALUE"
#     }
# }
