<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<title>{{ page.title }}</title>
</head>
<body>
	Demo content page, need to add set lang mechanism by calling `/i18n/set-lang?lang=fr`.
	<h1>
		{{ page.title }}
	</h1>
	{{ page.get_content() }}
</body>
</html>
